/* $Workfile: OtxData.h $   $Revision: 11 $    $Modtime: 12/30/03 10:51a $  */
#ifndef OTX_DATA_H
#define OTX_DATA_H
/******************************************************************************

  @doc PublicHwApi OtxData

  Copyright (C) 1998 - 2003 Odin TeleSystems Inc., All Rights Reserved

  OTX Generic Hardware Driver API

  @module
  OtxData | OTX Serial Data Manipulation Function Prototypes

  @contents2
  OtxData.h |

  @index func | OtxData

  @contents2
  OTX Serial Data Manipulation Function Prototypes - OtxDataXXX() | Functions available for Data Manipulations

  @head3 OtxDataXXX() Function Reference |

  @index func | OtxData

******************************************************************************/

#include "OtxDef.h"
#include "OtxType.h"

#include "OtxDataD.h"

#ifdef __cplusplus
extern "C" {
#endif


/******************************************************************************

  @func
    Initialize a Data Converter Logical Device. A Data Converter transforms
    data from one data format to another.

  @comm
    data is transferred into Data Converter through an input pipe, after 
    the data is transformed, it is transmitted to an output pipe.
        
  @ex |
    // Create Data Converter (for cross-connection with the DSP)
    result = OtxDrvCreateLogicalDevice(
               g_hPhysDevs.hDsp0, 
               OTX_LDEVICE_DATA_CONVERTER, 
               g_hEventQueue, 
               i, 
               &g_sqDataConverter.hHandle); 

    // DTMF data (just an example) as the input data to Data Convertor,
    // pipe creation, connection for DTMF needed to be done before this call. 
    result = OtxDrvConnectLogicalDevice(
               g_sqDtmfDetector.hPipe,  
               -1,  
               g_sqDataConverter.hHandle,  
               -1); 

    // create a pipe for output data from Data Converter
    ts = 5;
    memset(sqTimeSlotMask, 0, 32 * sizeof(OTX_UINT8));
    sqTimeSlotMask[ts] = 0xFF;
    nCapacity = 64;
    
    result = OtxDrvCreatePipe(
               nCapacity, 
               &g_sqDataConverter.hPipe); 

    // connect pipe from DSP0 (Data Convertor) to Li0
    result = OtxDrvConnectPipe(
               g_sqDataConverter.hPipe, 
               OTX_PIPE_INPUT,    
               g_hPhysDevs.hDsp0, 
               -1, 
               sqTimeSlotMask, 
               32); 

    result = OtxDrvConnectPipe(
               g_sqDataConverter.hPipe, 
               OTX_PIPE_OUTPUT,   
               g_hPhysDevs.hLi0,  
               -1, 
               sqTimeSlotMask, 
               32); 
    
    // connect Data Convertor device to the pipe 
    result = OtxDrvConnectLogicalDevice(
               g_sqDataConverter.hHandle,  
               -1, 
               g_sqDataConverter.hPipe,  
               -1); 

    // initialize the Data Converter, convert data from U-law to 8-bit unsigned interger
    result = OtxDataConverterInit(
               g_sqDataConverter.hHandle, 
               OTX_DATA_FORMAT_COMPAND8_U_LAW, 
               OTX_DATA_FORMAT_UINT8); 

    // enable the Data Converter
    result = OtxDrvEnable(
               g_sqDataConverter.hHandle, 
               OTX_TASK_SYNC, 
               5000L); 


  @xref
    <e OtxLogicalDeviceTypeE.OTX_LDEVICE_DATA_CONVERTER>
    <nl><t OtxDataFormatE>

******************************************************************************/
OTX_RESULT OTX_API OtxDataConverterInit(
  IN OTX_HANDLE       hDevice,          // @parm Handle to the logical Data Converter Device
  IN OtxDataFormatE   eDataFormatIn,    // @parm Data format coming in. See also <t OtxDataFormat>
  IN OtxDataFormatE   eDataFormatOut    // @parm Data format coming out. See also <t OtxDataFormat>
);


/******************************************************************************

  @func
    Initialize a Data Mixer Logical Device.

  @comm
    A Data Mixer multiplexes (mixes) N inputs to 1 output. Allows logical 
    device or pipe inputs to be connected together and mixed into one output.

  @xref
    <e OtxLogicalDeviceTypeE.OTX_LDEVICE_DATA_MIXER>

******************************************************************************/
OTX_RESULT OTX_API OtxDataMixerInit(
  IN OTX_HANDLE       hDevice           // @parm Handle to the logical Data Mixer Device
);



#ifdef __cplusplus
}  // extern "C"
#endif

/******************************************************************************

  Copyright (C) Odin TeleSystems Inc., 1998 - 2003


  All rights reserved. No part of this computer program may be reproduced,
  stored in any retrieval system, or transmitted, in any form or by any
  means, electronic, mechanical, photocopying, recording, or otherwise,
  without the prior written permission of Odin TeleSystems Inc., or without
  a permission stipulated in the agreement/contract under which this computer
  program was supplied.

******************************************************************************/
#endif  // OTX_DATA_H
